@@ -1,6 +1,6 @@
 package LLVM::Builder;
 {
-  $LLVM::Builder::VERSION = '0.08';
+  $LLVM::Builder::VERSION = '0.09';
 }
 
 use strict;
@@ -12,7 +12,7 @@ LLVM::Builder - LLVM builder class
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
@@ -55,6 +55,10 @@ L<LLVM::Value> C<$if> representing the condition (e.g. it can be the value
 returned by a icmp or fcmp instruction) and two L<LLVM::BasicBlock>: the first
 executed if the condition is true, the second executed otherwise.
 
+=head2 unreachable( )
+
+Append an unreachable instruction to the block.
+
 =head1 BINARY OPERATIONS
 
 The binary operations require two arguments of the same L<LLVM::Type> and
@@ -131,6 +135,16 @@ Append an or instruction to the block and name the result C<$name>.
 
 Append a xor instruction to the block and name the result C<$name>.
 
+=head1 CONVERSION OPERATIONS
+
+See the L<LLVM reference|http://llvm.org/docs/LangRef.html#otherops> for more
+information about the single instructions.
+
+=head2 trunc( $ty, $value, $out, $name )
+
+Append a trunc instruction which takes a L<LLVM::Value> and the conversion
+output L<LLVM::Type>, and name the result C<$name>.
+
 =head1 OTHER OPERATIONS
 
 See the L<LLVM reference|http://llvm.org/docs/LangRef.html#otherops> for more
